is_new_provider_registration

Function is_new_provider_registration 

pub fn is_new_provider_registration(
    provider: &CapabilityProvider,
    before: &ProviderRegistrationSnapshot,
) -> bool
True when provider did not exist in the snapshot or has since taken over its stable id with a new Atlas registration generation.