pub struct GetRobotContextResponse {Show 15 fields
pub pose_known: bool,
pub map_id: String,
pub x: f64,
pub y: f64,
pub z: f64,
pub yaw: f64,
pub room_id: String,
pub room_name: String,
pub containing_area_ids: Vec<String>,
pub containing_area_names: Vec<String>,
pub nearby_objects: Vec<Object>,
pub observed_at_unix: f64,
pub snapshot_at_unix: f64,
pub stale: bool,
pub reason: String,
}Fields
pose_known: boolmap_id: Stringx: f64y: f64z: f64yaw: f64room_id: Stringroom_name: Stringcontaining_area_ids: Vec<String>containing_area_names: Vec<String>nearby_objects: Vec<Object>observed_at_unix: f64snapshot_at_unix: f64stale: boolreason: StringTrait Implementations
Sourceimpl Clone for GetRobotContextResponse
impl Clone for GetRobotContextResponse
Sourcefn clone(&self) -> GetRobotContextResponse
fn clone(&self) -> GetRobotContextResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetRobotContextResponse
impl Debug for GetRobotContextResponse
Sourceimpl Default for GetRobotContextResponse
impl Default for GetRobotContextResponse
Sourceimpl Message for GetRobotContextResponse
impl Message for GetRobotContextResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetRobotContextResponse
impl PartialEq for GetRobotContextResponse
Sourcefn eq(&self, other: &GetRobotContextResponse) -> bool
fn eq(&self, other: &GetRobotContextResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GetRobotContextResponse