pub fn is_new_provider_registration(
provider: &CapabilityProvider,
before: &ProviderRegistrationSnapshot,
) -> boolExpand description
True when provider did not exist in the snapshot or has since taken over
its stable id with a new Atlas registration generation.